@@ -6,17 +6,17 @@
 #    By: charles <charles.cabergs@gmail.com>        +#+  +:+       +#+         #
 #                                                 +#+#+#+#+#+   +#+            #
 #    Created: 2020/07/15 18:24:52 by charles           #+#    #+#              #
-#    Updated: 2021/02/05 17:40:00 by charles          ###   ########.fr        #
+#    Updated: 2021/02/27 20:35:46 by cacharle         ###   ########.fr        #
 #                                                                              #
 # ############################################################################ #
 
-import minishell_test.config as config
+from minishell_test.config import Config
 from minishell_test.suite.decorator import suite
 from minishell_test.hooks import (
     error_line0,
     platform_status,
     discard,
-    replace_double_semi_colon,
+    replace_double,
     error_eof_to_expected_token
 )
 
@@ -49,11 +49,11 @@ def suite_end(test):
     test("; ;", hook=error_line0, hook_status=platform_status(2, 1))
     test("; ; ;", hook=error_line0, hook_status=platform_status(2, 1))
     test("echo a ; ; echo b", hook=error_line0, hook_status=platform_status(2, 1))
-    test(";;", hook=[error_line0, replace_double_semi_colon], hook_status=platform_status(2, 1))
-    test(";;;", hook=[error_line0, replace_double_semi_colon], hook_status=platform_status(2, 1))
-    test(";;;;;", hook=[error_line0, replace_double_semi_colon], hook_status=platform_status(2, 1))
-    test("echo a ;; echo b", hook=[error_line0, replace_double_semi_colon], hook_status=platform_status(2, 1))
-    test("echo a ;;;;; echo b", hook=[error_line0, replace_double_semi_colon], hook_status=platform_status(2, 1))
+    test(";;", hook=[error_line0, replace_double(";")], hook_status=platform_status(2, 1))
+    test(";;;", hook=[error_line0, replace_double(";")], hook_status=platform_status(2, 1))
+    test(";;;;;", hook=[error_line0, replace_double(";")], hook_status=platform_status(2, 1))
+    test("echo a ;; echo b", hook=[error_line0, replace_double(";")], hook_status=platform_status(2, 1))
+    test("echo a ;;;;; echo b", hook=[error_line0, replace_double(";")], hook_status=platform_status(2, 1))
     test("ls " + 40 * " ; ls", setup="touch a b c")
     test("ls " + 80 * " ; ls", setup="touch a b c")
     test("ls " + 40 * " ; ls" + ";", setup="touch a b c")
@@ -241,10 +241,10 @@ def suite_syntax_error(test):
     test("> a ; a",  hook=error_line0)
     test("< a ; a",  hook=error_line0)
     test(">> a ; a", hook=error_line0)
-    test(config.LOREM + " > >" + config.LOREM, hook=error_line0, hook_status=platform_status(2, 1))
-    test(config.LOREM + " < <" + config.LOREM, hook=error_line0, hook_status=platform_status(2, 1))
-    test(config.LOREM + " ; |" + config.LOREM, hook=error_line0, hook_status=platform_status(2, 1))
-    test(config.LOREM + " | ;" + config.LOREM, hook=error_line0, hook_status=platform_status(2, 1))
+    test(Config.lorem + " > >" + Config.lorem, hook=error_line0, hook_status=platform_status(2, 1))
+    test(Config.lorem + " < <" + Config.lorem, hook=error_line0, hook_status=platform_status(2, 1))
+    test(Config.lorem + " ; |" + Config.lorem, hook=error_line0, hook_status=platform_status(2, 1))
+    test(Config.lorem + " | ;" + Config.lorem, hook=error_line0, hook_status=platform_status(2, 1))
 
 
 @suite(bonus=True)
@@ -289,8 +289,8 @@ def suite_syntax_error_bonus(test):
     test("() a",    hook=error_line0, hook_status=platform_status(2, 1))
     test("( a",     hook=[error_line0, error_eof_to_expected_token], hook_status=platform_status(2, 1))
     test(") a",     hook=error_line0, hook_status=platform_status(2, 1))
-    test(config.LOREM + " && &&" + config.LOREM, hook=error_line0, hook_status=platform_status(2, 1))
-    test(config.LOREM + " || ||" + config.LOREM, hook=error_line0, hook_status=platform_status(2, 1))
-    test(config.LOREM + " ( ("   + config.LOREM, hook=error_line0, hook_status=platform_status(2, 1))
-    test(config.LOREM + " ) )"   + config.LOREM, hook=error_line0, hook_status=platform_status(2, 1))
+    test(Config.lorem + " && &&" + Config.lorem, hook=error_line0, hook_status=platform_status(2, 1))
+    test(Config.lorem + " || ||" + Config.lorem, hook=error_line0, hook_status=platform_status(2, 1))
+    test(Config.lorem + " ( ("   + Config.lorem, hook=error_line0, hook_status=platform_status(2, 1))
+    test(Config.lorem + " ) )"   + Config.lorem, hook=error_line0, hook_status=platform_status(2, 1))
     test("(); () ;() ;() ;() ;() ;() ;() ;() ;() ;a",    hook=error_line0, hook_status=platform_status(2, 1))
